Description Usage Arguments Author(s) References Examples
This returns the estimated parameters from the original "Glmnet" package, which can provide a comparison of two methods.
1 | lasso1(x,y)
|
x |
Predicted variable |
y |
Response variable |
Sujit K. Ghosh, Kaiyuan Duan, Guangjie Yu
A Fast Automatic Variable Selection Method for LinearRegression Model
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.